MAIN_CONTROLLER: str = "__main__"

LEFT_FRONT_WHEEL_SPEED_SENSOR: str = "lfwss"
RIGHT_FRONT_WHEEL_SPEED_SENSOR: str = "rfwss"
LEFT_REAR_WHEEL_SPEED_SENSOR: str = "lrwss"
RIGHT_REAR_WHEEL_SPEED_SENSOR: str = "rrwss"
MIDDLE_REAR_WHEEL_SPEED_SENSOR: str = "mrwss"
